# bingwall
bing.com change it wallpaper every day and it allways is too beauty so i wrote a simple script with python to download them.

##### this script is wrote just for fun for any OS. such as Gnu/Linux, Windows, Android, etc

i tryed program under ["Ubuntu", "Android"] with python3. it's work prefectly.
if there is any bug or suggest you can fix it by your self or tel me.

### if you are in linux base:
you can soft link this script to `/etc/cron.daily` so then you can have daily wallpaper of [bing](https://www.bing.com).

and if you don't like auto run, you can soft link it to `~/.local/bin`

### or if you have android, you sould use _termux_

### and if you are using windows:
you can use *windows task scheduler* to download daily wallpaper.

or you can run it manualy